#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl
version:              5.7.0.3
visibility:           public
id:                   fgl-5.7.0.3-1I1iCHw3i3F1h91rICmN9k
key:                  fgl-5.7.0.3-1I1iCHw3i3F1h91rICmN9k
license:              BSD-3-Clause
maintainer:           Ivan.Miljenovic@gmail.com
author:               Martin Erwig, Ivan Lazar Miljenovic
synopsis:             Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.

    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

category:             Data Structures, Graphs
abi:                  97dd0401040aac9ac2384dd1ccfcef00
exposed:              True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree

hidden-modules:       Paths_fgl
import-dirs:          /usr/lib/ghc-8.10.5/site-local/fgl-5.7.0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/fgl-5.7.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/fgl-5.7.0.3
hs-libraries:         HSfgl-5.7.0.3-1I1iCHw3i3F1h91rICmN9k
depends:
    array-0.5.4.0 base-4.14.2.0 containers-0.6.4.1 deepseq-1.4.4.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html:         /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

